/***************************************************************************
 * Copyright 2013 Kieker Project (http://kieker-monitoring.net)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 ***************************************************************************/

package kieker.webgui.web.beans.view;

import java.util.Collections;
import java.util.List;

import javax.annotation.PostConstruct;
import javax.faces.context.FacesContext;

import kieker.webgui.web.beans.application.ProjectsBean;

import org.primefaces.event.SelectEvent;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Scope;
import org.springframework.stereotype.Component;

/**
 * The {@link CurrentProjectOverviewBean} contains the necessary data behind an instance of the project overview.<br>
 * </br>
 * 
 * The class is a Spring managed bean with view scope.
 * 
 * @author Nils Christian Ehmke
 */
@Component
@Scope("view")
public class CurrentProjectOverviewBean {

	private List<String> availableProjects;
	private String selectedProjectName;

	@Autowired
	private ProjectsBean projectsBean;

	/**
	 * Creates a new instance of this class. <b>Do not use this constructor. This bean is Spring managed.</b>
	 */
	public CurrentProjectOverviewBean() {
		this.availableProjects = Collections.emptyList();
	}

	/**
	 * This method initializes the bean. <b>Do not call this method manually. It will only be accessed by Spring.</b>
	 */
	@PostConstruct
	protected void initialialize() {
		// Make sure that the initialization will only be done for the init request.
		if (!FacesContext.getCurrentInstance().isPostback()) {
			this.updateAvailableProjects();
		}
	}

	/**
	 * This is the event handler used to select a row instantaneously.
	 * 
	 * @param event
	 *            The select event.
	 */
	public void rowSelectHandler(final SelectEvent event) {
		this.setProjectName((String) event.getObject());
	}

	/**
	 * Updates the list with the available availableProjects.
	 */
	public void updateAvailableProjects() {
		this.availableProjects = this.projectsBean.getProjects();
	}

	public List<String> getProjects() {
		return this.availableProjects;
	}

	public String getProjectName() {
		return this.selectedProjectName;
	}

	public void setProjectName(final String projectName) {
		this.selectedProjectName = projectName;
	}
}
